@@ -122,7 +122,7 @@ class MainWindow : public QMainWindow {
 
     void reloadOpenAiControls();
 
-    void setCurrentNoteText(QString text);
+    void setCurrentNoteText(const QString &text);
 
     void setCurrentNote(Note note, bool updateNoteText = true, bool updateSelectedNote = true,
                         bool addPreviousNoteToHistory = true);
@@ -728,6 +728,8 @@ class MainWindow : public QMainWindow {
 
     void on_actionReattach_panels_triggered();
 
+    void on_actionManage_Nextcloud_Deck_cards_triggered();
+
    public:
     /** Settings access **/
     static bool isInDistractionFreeMode();
@@ -1164,4 +1166,5 @@ class MainWindow : public QMainWindow {
     void setupNoteRelationScene();
     void updateNoteGraphicsView();
     void addDirectoryToDirectoryWatcher(const QString &path);
+    bool nextCloudDeckCheck();
 };
